use axum::extract::FromRef;

use rear::admin::state::{AdminState, SharedRegistry};
use rear::service::templates;

#[derive(Clone)]
pub struct AppState {
    pub templates: templates::Templates,
    pub admin: SharedRegistry,
}

impl FromRef<AppState> for templates::Templates {
    fn from_ref(app_state: &AppState) -> templates::Templates {
        app_state.templates.clone()
    }
}

impl FromRef<AppState> for SharedRegistry {
    fn from_ref(app_state: &AppState) -> SharedRegistry {
        app_state.admin.clone()
    }
}

impl AdminState for AppState {
    fn get_templates(&self) -> &templates::Templates {
        &self.templates
    }

    fn get_registry(&self) -> SharedRegistry {
        self.admin.clone()
    }
}
